# The CADET-Research Data Management toolbox

Welcome to CADET-RDM, a project by the Forschungszentrum Jülich.

This toolbox aims to help track and version control:
- input data
- code
- software versions
- output data

and allow for easy sharing, integration, and reproduction of generated results. 

## Documentation

The documentation contains a user guide with helpful information on how to install CADET-RDM, how to quickly start working with it and a more detailed explaination of its tools.
The documentation can be found [here](https://cadet-rdm.readthedocs.io).